#!/bin/bash -e

  export COMPSS_PYTHON_VERSION=3.9.10
  module load COMPSs/3.3

  # Define script variables
  scriptDir=$(pwd)/$(dirname $0)
  execFile=${scriptDir}/src/cholesky.py
  appPythonpath=${scriptDir}/src/

  # Retrieve arguments
  numNodes=$1
  executionTime=$2
  tracing=$3

  # Leave application args on $@
  shift 3

  export ComputingUnits=$3

  # Enqueue the application
  pycompss job submit \
    --provenance \
    --qos=debug \
    --num_nodes=$numNodes \
    --exec_time=$executionTime \
    --worker_working_dir=$(pwd) \
    --tracing=$tracing \
    --graph=true \
    --pythonpath=$appPythonpath \
    --lang=python \
    $execFile $@

 
######################################################
# APPLICATION EXECUTION EXAMPLE
# Call:
#       ./launch_cholesky.sh <NUMBER_OF_NODES> <EXECUTION_TIME> <TRACING> <SIZE> <BSIZE> <ComputingUnits> <MKL_NUM_THREADS> <verify_result>
#
# Example:
#       ./launch_cholesky.sh 2 10 false 4 512 8 16 False
#
#####################################################
